@@ -2,7 +2,7 @@ import gzip
 import os
 import re
 from timeit import default_timer
-from typing import Callable, Tuple
+from typing import Callable, List, Optional, Tuple
 
 from fastapi import FastAPI
 from prometheus_client import Gauge
@@ -183,6 +183,7 @@ class PrometheusFastApiInstrumentator:
         should_gzip: bool = False,
         endpoint: str = "/metrics",
         include_in_schema: bool = True,
+        tags: Optional[List[str]] = None,
     ):
         """Exposes endpoint for metrics.
 
@@ -197,6 +198,8 @@ class PrometheusFastApiInstrumentator:
 
             endpoint: Endpoint on which metrics should be exposed.
             include_in_schema: Should the endpoint show up in the documentation?
+            tags (List[str], optional): If you manage your routes with tags.
+                Defaults to None.
 
         Raises:
             ValueError: If `prometheus_multiproc_dir` env var is found but
@@ -232,7 +235,7 @@ class PrometheusFastApiInstrumentator:
         else:
             registry = REGISTRY
 
-        @app.get(endpoint, include_in_schema=include_in_schema)
+        @app.get(endpoint, include_in_schema=include_in_schema, tags=tags)
         def metrics(request: Request):
             if should_gzip and "gzip" in request.headers.get("Accept-Encoding", ""):
                 resp = Response(content=gzip.compress(generate_latest(registry)))
